@@ -6,6 +6,7 @@ from phply.phpast import *
 
 import nose.tools
 import pprint
+import sys
 
 parser = make_parser()
 
@@ -234,20 +235,31 @@ EOT;
                        BinaryOp('.',
                                 BinaryOp('.',
                                          BinaryOp('.',
-                                                  BinaryOp('.',
-                                                           BinaryOp('.',
-                                                                    BinaryOp('.',
-                                                                             'This',
-                                                                             ' is a "'),
-                                                                    Variable('$heredoc')),
-                                                           '" with some '),
-                                                  ObjectProperty(Variable('$embedded'),
-                                                                 'variables')),
-                                         '.\n'),
-                                'This'),
-                       ' is not the EOT; this is:')]),
+                                                  'This is a "',
+                                                  Variable('$heredoc')),
+                                         '" with some '),
+                                ObjectProperty(Variable('$embedded'),
+                                               'variables')),
+                       '.\nThis is not the EOT; this is:')]),
     ]
     eq_ast(input, expected)
+    if sys.version_info[0] < 3:
+        eq_ast(input.decode('utf-8'), expected)
+
+def test_heredoc_no_var():
+    input = r"""<?
+        echo <<<EOT
+This is a long
+heredoc without
+any variable.
+EOT;
+    ?>"""
+    expected = [
+        Echo(['This is a long\nheredoc without\nany variable.'])
+    ]
+    eq_ast(input, expected)
+    if sys.version_info[0] < 3:
+        eq_ast(input.decode('utf-8'), expected)
 
 def test_function_calls():
     input = r"""<?
